@@ -32,6 +32,7 @@ define("handler_path", default="handlers", type=str, help="处理器文件存储
 define("echo_sql", default=True, type=bool, help="是否启用SQL输出")
 define("async_enable", default=False, type=bool, help="是否启用异步")
 define("max_limit", default=500, type=int, help="单次查询最大数量")
+define("eureka_config", default={}, type=dict, help="eureka配置")
 define("eureka_enable", default=False, type=bool, help="是否启用eureka")
 define("eureka_server", default="", type=str, help="eureka server地址")
 define("eureka_instance_name", default="", type=str, help="eureka实例名称，大写")
@@ -46,6 +47,7 @@ define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调
 define("scheduler_enable", default=False, type=bool, help="Tornado任务调度")
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
 define("scheduler_options", default={}, type=dict, help="Tornado任务调度选项")
+define("nacos_config", default={}, type=dict, help="nacos配置")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -140,17 +142,51 @@ class WebServer:
         self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024, xheaders=True)  # 500M
 
     def start(self, num_processes: Optional[int] = 1, max_restarts: int = None):
-        if options.eureka_enable:
+        if options.eureka_config.get("enable"):
             import py_eureka_client.eureka_client as eureka_client
-            eureka_server = options.eureka_server
-            eureka_instance_name = options.eureka_instance_name if options.eureka_instance_name \
-                else options.application_name
-            eureka_instance_ip = options.eureka_instance_ip if options.eureka_instance_ip else "127.0.0.1"
-            eureka_instance_port = options.eureka_instance_port if options.eureka_instance_port else options.port
-            eureka_client.init(eureka_server=eureka_server,
+            eureka_instance_name = options.eureka_config.get("instance_name") if options.eureka_config.get(
+                "instance_name") else options.application_name
+            eureka_instance_ip = options.eureka_config.get("instance_ip") if options.eureka_config.get(
+                "instance_ip") else "127.0.0.1"
+            eureka_instance_port = options.eureka_config.get("instance_port") if options.eureka_config.get(
+                "instance_port") else options.port
+            eureka_client.init(eureka_server=options.eureka_config.get("eureka_server"),
                                app_name=eureka_instance_name,
                                instance_ip=eureka_instance_ip,
                                instance_port=eureka_instance_port)
+        if options.nacos_config.get("enable"):
+            import nacos
+            nacos_service_name = options.nacos_config.get("service_name") if options.nacos_config.get(
+                "service_name") else options.application_name
+            nacos_namespace = options.nacos_config.get("namespace") if options.nacos_config.get(
+                "namespace") else "public"
+            nacos_instance_ip = options.nacos_config.get("instance_ip") if options.nacos_config.get(
+                "instance_ip") else "127.0.0.1"
+            nacos_instance_port = options.nacos_config.get("instance_port") if options.nacos_config.get(
+                "instance_port") else options.port
+            nacos_instance_weight = options.nacos_config.get("instance_weight") if options.nacos_config.get(
+                "instance_weight") else 1.0
+            nacos_instance_enable = options.nacos_config.get("instance_enable") if options.nacos_config.get(
+                "instance_enable") else True
+            nacos_instance_healthy = options.nacos_config.get("instance_healthy") if options.nacos_config.get(
+                "instance_healthy") else True
+            nacos_instance_ephemeral = options.nacos_config.get("instance_ephemeral") if options.nacos_config.get(
+                "instance_ephemeral") else False
+            nacos_instance_group_name = options.nacos_config.get("instance_group_name") if options.nacos_config.get(
+                "instance_group_name") else "DEFAULT_GROUP"
+            nacos_client = nacos.NacosClient(server_addresses=options.nacos_config.get("server_addresses"),
+                                             namespace=nacos_namespace,
+                                             endpoint=options.nacos_config.get("endpoint"),
+                                             ak=options.nacos_config.get("ak"), sk=options.nacos_config.get("sk"),
+                                             username=options.nacos_config.get("username"),
+                                             password=options.nacos_config.get("password"))
+            nacos_client.add_naming_instance(service_name=nacos_service_name, ip=nacos_instance_ip,
+                                             port=nacos_instance_port,
+                                             cluster_name=options.nacos_config.get("cluster_name"),
+                                             weight=nacos_instance_weight,
+                                             metadata=options.nacos_config.get("instance_metadata"),
+                                             enable=nacos_instance_enable, healthy=nacos_instance_healthy,
+                                             ephemeral=nacos_instance_ephemeral, group_name=nacos_instance_group_name)
         self.server.listen(options.port)
         self.server.start(num_processes, max_restarts)
         logging.info(f"start server : {options.application_name}")
